(***********************************************************************)
(*                                                                     *)
(*                           CIME Caml                                 *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 1997 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

open Lib_strings;;

type t =
   |  Fr | Uk | Es | De | It;;

let prefix_of_file_name s = from_to_char s 0 '.';;

let suffix_of_file_name s = from_char_to_end s '.';;

(* Try to detect the language in which a file is written. We suppose that
   the language is indicated by a proper ``internal extension'', that
   is a character string delimited by [-] and [.] characters (as [fra]
   in [foo-fra.html]). If [-] is not found, then the sub-string from
   the beginning of [s] to the position of [.] is returned (for instance [fra]
   in [fra.htm]). If neither [-] nor [.] is found then the entire name
   is returned. *)
(*
Could simply be
let lang_suffix s =
 let len = String.length s in
 let minus =
  try pos_string_rev s (len - 1) '-' with Not_found -> -1 in
 let dot =
  try pos_string_rev s (len - 1) '.' with Not_found -> len in
 String.sub s (minus + 1) (dot - minus - 1);;
*)

let lang_suffix s =
 let len = String.length s in
 let minus =
  try pos_string_rev s (len - 1) '-' with Not_found -> -1 in
 let dot =
  try pos_string_rev s (len - 1) '.' with Not_found -> len in
 match minus, dot with
 | -1, -1 -> s
 | -1, 0 -> ""
 | -1, lastdot ->
    begin try
     let antedot = pos_string_rev s (lastdot - 1) '.' in
     String.sub s (antedot + 1) (lastdot - antedot - 1)
    with Not_found -> String.sub s (minus + 1) (dot - minus - 1) end
 | minus, -1 -> String.sub s (minus + 1) (dot - minus - 1)
 |  _, _ -> String.sub s (minus + 1) (dot - minus - 1);;

let lang_of_file_name s =
  match lang_suffix s with
  | "fra" | "fr" -> Fr
  | "eng" | "en" | "uk" -> Uk
  | "esp" | "es" -> Es
  | "deu" | "de" -> De
  | "ita" | "it" -> It
  | _ -> Uk;;

let suffix_of_lang = function
  | Fr -> "fra"
  | Uk -> "eng"
  | Es -> "esp"
  | De -> "deu"
  | It -> "ita";;


