(***********************************************************************)
(*                                                                     *)
(*                           CIME Caml                                 *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 1997 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

type t =
   | Fr | Uk | Es | De | It;;
 (* The type defining the languages that are currently supported by Caml.
    In fact this file only implements the translation for [Fr] and [Uk]. *)

val prefix_of_file_name : string -> string;;
val suffix_of_file_name : string -> string;;
val lang_suffix : string -> string;;
(* Return the ``internal suffix'' of a file name, that is a sub-string
   delimited by [-] and [.] characters (as [fra] in [foo-fra.html] or
   [eng] in [foo-eng.html]). Raise [Not_found], if there is no such
   suffix. *)

val lang_of_file_name : string -> t;;
(* Return the language in which a file is written from its name. We
   suppose that the language is indicated by a proper ``internal
   suffix'', as defined by [lang_suffix]. 
   Suffixes are respectively ["fra"] or ["fr"] for [Fr],
   ["eng"] or ["en"] or ["uk"] for [Uk],
   ["esp"] or ["es"] for [Es], ["deu"] or ["de"] for [De],
   and ["ita"] or ["it"] for [It].
   Default to [Uk], if no suffix has been found. *)

val suffix_of_lang : t -> string;;
(* Returns a normalized three characters suffix value for a language. *)
