(***********************************************************************)
(*                                                                     *)
(*                           CIME Caml                                 *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 1997 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

(* The path machinery:
   we define a current list of directories to look up for finding files. *)
exception Empty;;

let current = ref [];;

let push p = current := p :: !current;;
let pop () =
 match !current with
 | [] -> raise Empty
 | _ :: rest -> current := rest;;

let iter f path s =
 try f s with
 | Sys_error _ as x ->
   let rec do_in = function
   | [] -> raise x
   | p :: pts ->
     try f (Filename.concat p s) with
     | Sys_error _ -> do_in pts in
   do_in path;;

let open_in s =
 if Filename.is_implicit s
 then iter Pervasives.open_in !current s
 else open_in s;;

let open_out s =
 if Filename.is_implicit s
 then iter Pervasives.open_out !current s
 else open_out s;;

