(***********************************************************************)
(*                                                                     *)
(*                           CIME Caml                                 *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 1997 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

exception Empty;;
(* This exception is raised when [pop] is called and the current
   directory path is empty. *)
val current : string list ref;;
val push : string -> unit;;
val pop : unit -> unit;;
(* The path machinery:
   define a current list of directories to search to find files. *)
val iter : (string -> 'a) -> string list -> string -> 'a;;
(* [iter f path s] applies [f] on any files named [s] in
   the path, and returns the result of the first call that does not
   fail by raising the exception [Sys_error]. For instance,
   [iter open_in "foo"] searches the current path for a file
   ["foo"] and returns an input channel to that file. *) 
val open_in : string -> in_channel;;
val open_out : string -> out_channel;;
(* Opening files in the current path. Equivalent to the regular open
   primitives if the file name argument is not implicit. *)
